pub struct TensorStatsComparisonRow {
pub label: String,
pub rms_a: f64,
pub rms_b: f64,
pub rms_ratio: Option<f64>,
pub abs_max_ratio: Option<f64>,
pub non_finite_a: u64,
pub non_finite_b: u64,
pub samples_a: usize,
pub samples_b: usize,
pub runs_a: usize,
pub runs_b: usize,
}Fields
label: Stringrms_a: f64rms_b: f64rms_ratio: Option<f64>abs_max_ratio: Option<f64>non_finite_a: u64non_finite_b: u64samples_a: usizeEvents averaged into rms_a/abs_max for this label (duplicates included).
samples_b: usizeruns_a: usizeCohort runs that contained this label; compare against the cohort run totals to see whether an average covers the whole cohort or only part of it.
runs_b: usizeTrait Implementations
Sourceimpl Clone for TensorStatsComparisonRow
impl Clone for TensorStatsComparisonRow
Sourcefn clone(&self) -> TensorStatsComparisonRow
fn clone(&self) -> TensorStatsComparisonRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TensorStatsComparisonRow
impl Debug for TensorStatsComparisonRow
Sourceimpl<'de> Deserialize<'de> for TensorStatsComparisonRow
impl<'de> Deserialize<'de> for TensorStatsComparisonRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TensorStatsComparisonRow
impl PartialEq for TensorStatsComparisonRow
Sourceimpl Serialize for TensorStatsComparisonRow
impl Serialize for TensorStatsComparisonRow
impl StructuralPartialEq for TensorStatsComparisonRow