pub struct NumericDomainViolation {
pub edge_or_node: NodeId,
pub op: String,
pub requires: String,
pub producer_domain: String,
pub proven: bool,
pub impact: NumericImpact,
pub span: SrcSpan,
pub message: String,
pub library_cite: Option<String>,
}Expand description
A partial function applied to a domain that can attain a forbidden endpoint.
Fields
edge_or_node: NodeIdop: Stringrequires: Stringproducer_domain: Stringproven: boolimpact: NumericImpactspan: SrcSpanmessage: Stringlibrary_cite: Option<String>Source citation when the hazard came from an expanded library body.