Module phase

Module phase 

Train vs inference execution phase for static graphs and runtime traces.

Enums

ExecutionPhase
Whether analysis or profiling targets training (autograd) or inference (no-grad).

Functions

entrypoint_phases
Classify which static graphs to build for an entrypoint.