QueryKind

Enum QueryKind 

pub enum QueryKind {
Show 29 variants Summary, Doctor, Architecture, Cargo, Components, Component, Modules, Composition, Assembly, Pipeline, Stages, Artifacts, Entrypoints, Functions, Function, Parameters, Parameter, Tensors, Tensor, Operations, Operation, Optimizers, Runtime, Findings, Path, ModelImprovement, GraphTrain, GraphInfer, Profile,
}

Variants



Summary



Doctor



Architecture



Cargo



Components



Component



Modules



Composition



Assembly



Pipeline



Stages



Artifacts



Entrypoints



Functions



Function



Parameters



Parameter



Tensors



Tensor



Operations



Operation



Optimizers



Runtime



Findings



Path



ModelImprovement

Compact agent-oriented rollup for model repair and improvement workflows.



GraphTrain

Phase-filtered graph: tensors + operations for training autograd paths.



GraphInfer

Phase-filtered graph: tensors + operations for inference no-grad paths.



Profile

Runtime profile rollup: operation and edge timings merged from a v3 trace.