pub struct ExpectedIdentity {
pub analysis_id: Option<String>,
pub build_id: Option<String>,
}Expand description
Expected analysis/build identity supplied by an importer when correlating a trace.
Only fields that are Some on both this value and the trace metadata are compared.
Omitted optional identity on either side is compatible (backward compatible).
Fields
analysis_id: Option<String>build_id: Option<String>Trait Implementations
Sourceimpl Clone for ExpectedIdentity
impl Clone for ExpectedIdentity
Sourcefn clone(&self) -> ExpectedIdentity
fn clone(&self) -> ExpectedIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExpectedIdentity
impl Debug for ExpectedIdentity
Sourceimpl Default for ExpectedIdentity
impl Default for ExpectedIdentity
Sourcefn default() -> ExpectedIdentity
fn default() -> ExpectedIdentity
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExpectedIdentity
impl<'de> Deserialize<'de> for ExpectedIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExpectedIdentity
Sourceimpl PartialEq for ExpectedIdentity
impl PartialEq for ExpectedIdentity
Sourceimpl Serialize for ExpectedIdentity
impl Serialize for ExpectedIdentity
impl StructuralPartialEq for ExpectedIdentity