pub struct NodeMemoryMetrics {
pub direct_allocated_bytes: Option<u64>,
pub subtree_peak_live_bytes: Option<u64>,
pub subtree_residual_bytes: Option<u64>,
pub output_dense_bytes: Option<u64>,
}Expand description
Per-node logical memory evidence. None means that metric was not observed.
Fields
direct_allocated_bytes: Option<u64>Unique storage bytes allocated directly by this span.
subtree_peak_live_bytes: Option<u64>Simultaneous live bytes from this span and descendants, clipped to the span interval.
subtree_residual_bytes: Option<u64>Subtree storage still live at the end of the span.
output_dense_bytes: Option<u64>Dense output tensor footprint metadata for an operation node.