pub struct CaptureContract {
pub measurement_scope: MeasurementScope,
pub operations: CoverageLevel,
pub tensors: CoverageLevel,
pub gradients: CoverageLevel,
pub gradient_contract: Option<GradientContract>,
pub logical_memory: CoverageLevel,
pub physical_memory: CoverageLevel,
pub device_timing: CoverageLevel,
pub required_semantic_labels: Vec<String>,
pub gpu_expected_semantic_labels: Vec<String>,
pub cpu_only_semantic_labels: Vec<String>,
}Fields
measurement_scope: MeasurementScopeoperations: CoverageLeveltensors: CoverageLevelgradients: CoverageLevelgradient_contract: Option<GradientContract>logical_memory: CoverageLevelphysical_memory: CoverageLeveldevice_timing: CoverageLevelrequired_semantic_labels: Vec<String>gpu_expected_semantic_labels: Vec<String>Required application spans expected to project onto the GPU. When both semantic-class lists are empty, all required semantic labels retain the legacy GPU-expected meaning.
cpu_only_semantic_labels: Vec<String>Required application spans that must not appear in an Nsight GPU projection report.
Implementations