pub struct ModelRun {
pub analyze: AnalyzeRequest,
pub report: ReportMode,
pub output: Option<PathBuf>,
pub diagnostics: Option<MessageFormat>,
pub fail_on_warning_error: bool,
pub deny_rules: Vec<String>,
pub check_baseline: Option<PathBuf>,
pub update_baseline: Option<PathBuf>,
pub audit: Option<AuditBundle>,
pub checkpoint: Option<PathBuf>,
pub verify_root: Option<String>,
}Expand description
One invocation of the shared model-mode engine.
Fields
analyze: AnalyzeRequestreport: ReportModeoutput: Option<PathBuf>diagnostics: Option<MessageFormat>When set, finding diagnostics are written to stderr in this format.
fail_on_warning_error: boolExit non-zero when findings include proven Error defects.
deny_rules: Vec<String>Exit non-zero when proven findings match any of these rule names.
check_baseline: Option<PathBuf>update_baseline: Option<PathBuf>audit: Option<AuditBundle>checkpoint: Option<PathBuf>Optional safetensors checkpoint merged before report/audit (header verify only).
verify_root: Option<String>VarBuilder root for safetensors checkpoint verification (default: first builder or vb).