pub struct NsightEvidence {Show 15 fields
pub status: GpuEvidenceStatus,
pub reason: Option<String>,
pub raw_report: Option<NsightArtifact>,
pub source_csv: Vec<NsightArtifact>,
pub provenance: NsightProvenance,
pub coverage: NsightCoverage,
pub correlation: NsightCorrelation,
pub diagnostics: Vec<String>,
pub limits: BTreeMap<String, ReportLimit>,
pub kernels: Vec<NsightSummaryRow>,
pub runtime_calls: Vec<NsightSummaryRow>,
pub memory_operations: Vec<NsightSummaryRow>,
pub nvtx_ranges: Vec<NsightTimelineRow>,
pub gpu_timeline: Vec<NsightTimelineRow>,
pub phase_attribution: Vec<PhaseGpuAttribution>,
}Fields
status: GpuEvidenceStatusreason: Option<String>raw_report: Option<NsightArtifact>source_csv: Vec<NsightArtifact>provenance: NsightProvenancecoverage: NsightCoveragecorrelation: NsightCorrelationdiagnostics: Vec<String>limits: BTreeMap<String, ReportLimit>kernels: Vec<NsightSummaryRow>runtime_calls: Vec<NsightSummaryRow>memory_operations: Vec<NsightSummaryRow>nvtx_ranges: Vec<NsightTimelineRow>gpu_timeline: Vec<NsightTimelineRow>phase_attribution: Vec<PhaseGpuAttribution>Implementations
Sourceimpl NsightEvidence
impl NsightEvidence
Sourcepub fn bind_to_trace(&mut self, run_id: &str, correlation_id: &str)
pub fn bind_to_trace(&mut self, run_id: &str, correlation_id: &str)
Bind normalized artifacts to the application trace that is consuming them.
Sourcepub fn load_optional(
dir: Option<&Path>,
expected_semantic_keys: &[String],
) -> Self
pub fn load_optional( dir: Option<&Path>, expected_semantic_keys: &[String], ) -> Self
Load official CSV reports. A missing or invalid capture manifest lowers provenance confidence without suppressing independently parseable GPU evidence.
pub fn load_optional_with_semantic_contract( dir: Option<&Path>, required_application_labels: &[String], gpu_expected_semantic_keys: &[String], cpu_only_semantic_keys: &[String], ) -> Self
pub fn load(dir: &Path, expected_semantic_keys: &[String]) -> Result<Self>
pub fn load_with_semantic_contract( dir: &Path, required_application_labels: &[String], gpu_expected_semantic_keys: &[String], cpu_only_semantic_keys: &[String], ) -> Result<Self>