Train vs inference execution phase for static graphs and runtime traces.
Enums
- Execution
Phase - Whether analysis or profiling targets training (autograd) or inference (no-grad).
Functions
- entrypoint_
phases - Classify which static graphs to build for an entrypoint.