QueryKind

Enum QueryKind 

pub enum QueryKind {
Show 26 variants Summary, Doctor, Architecture, Cargo, Components, Component, Modules, Composition, Assembly, Pipeline, Stages, Artifacts, Entrypoints, Functions, Function, Parameters, Parameter, Tensors, Tensor, Operations, Operation, Optimizers, Runtime, Findings, Path, ModelImprovement,
}

Variants



Summary



Doctor



Architecture



Cargo



Components



Component



Modules



Composition



Assembly



Pipeline



Stages



Artifacts



Entrypoints



Functions



Function



Parameters



Parameter



Tensors



Tensor



Operations



Operation



Optimizers



Runtime



Findings



Path



ModelImprovement

Compact agent-oriented rollup for model repair and improvement workflows.